@@ -177,6 +177,8 @@
 using std::cerr;
 using std::string;
 
+using namespace srchilite;
+
 static void yyerror( const char *s ) ;
 static void yyerror( const string &s ) ;
 
@@ -216,7 +218,7 @@ static bool includedFileNotFound = false;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 56 "./outlangdefparser.yy"
+#line 58 "./outlangdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
@@ -224,7 +226,7 @@ typedef union YYSTYPE
   int flag ;
 }
 /* Line 187 of yacc.c.  */
-#line 228 "outlangdefparser.cc"
+#line 230 "outlangdefparser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -237,7 +239,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 241 "outlangdefparser.cc"
+#line 243 "outlangdefparser.cc"
 
 #ifdef short
 # undef short
@@ -532,12 +534,12 @@ static const yytype_int8 yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const yytype_uint8 yyrline[] =
+static const yytype_uint16 yyrline[] =
 {
-       0,    72,    72,    75,    76,    79,    86,    93,    99,   105,
-     111,   117,   123,   129,   135,   141,   147,   153,   159,   165,
-     171,   177,   188,   194,   200,   206,   211,   215,   225,   228,
-     230,   233,   240,   247,   250,   252,   255
+       0,    74,    74,    77,    78,    81,    88,    95,   101,   107,
+     113,   119,   125,   131,   137,   143,   149,   155,   161,   167,
+     173,   179,   190,   196,   202,   208,   213,   217,   227,   230,
+     232,   235,   242,   249,   252,   254,   257
 };
 #endif
 
@@ -1483,7 +1485,7 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 80 "./outlangdefparser.yy"
+#line 82 "./outlangdefparser.yy"
     {
     textstyles->docTemplate = DocTemplate(*(yyvsp[(2) - (4)].string), *(yyvsp[(3) - (4)].string));
     delete (yyvsp[(2) - (4)].string);
@@ -1492,7 +1494,7 @@ yyreduce:
     break;
 
   case 6:
-#line 87 "./outlangdefparser.yy"
+#line 89 "./outlangdefparser.yy"
     {
     textstyles->noDocTemplate = DocTemplate(*(yyvsp[(2) - (4)].string), *(yyvsp[(3) - (4)].string));
     delete (yyvsp[(2) - (4)].string);
@@ -1501,7 +1503,7 @@ yyreduce:
     break;
 
   case 7:
-#line 94 "./outlangdefparser.yy"
+#line 96 "./outlangdefparser.yy"
     {
     textstyles->starting_template = *(yyvsp[(2) - (2)].string);
     delete (yyvsp[(2) - (2)].string);
@@ -1509,7 +1511,7 @@ yyreduce:
     break;
 
   case 8:
-#line 100 "./outlangdefparser.yy"
+#line 102 "./outlangdefparser.yy"
     {
     textstyles->style_separator = *(yyvsp[(2) - (2)].string);
     delete (yyvsp[(2) - (2)].string);
@@ -1517,7 +1519,7 @@ yyreduce:
     break;
 
   case 9:
-#line 106 "./outlangdefparser.yy"
+#line 108 "./outlangdefparser.yy"
     {
   textstyles->bold = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1525,7 +1527,7 @@ yyreduce:
     break;
 
   case 10:
-#line 112 "./outlangdefparser.yy"
+#line 114 "./outlangdefparser.yy"
     {
   textstyles->italics = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1533,7 +1535,7 @@ yyreduce:
     break;
 
   case 11:
-#line 118 "./outlangdefparser.yy"
+#line 120 "./outlangdefparser.yy"
     {
   textstyles->underline = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1541,7 +1543,7 @@ yyreduce:
     break;
 
   case 12:
-#line 124 "./outlangdefparser.yy"
+#line 126 "./outlangdefparser.yy"
     {
   textstyles->fixed = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1549,7 +1551,7 @@ yyreduce:
     break;
 
   case 13:
-#line 130 "./outlangdefparser.yy"
+#line 132 "./outlangdefparser.yy"
     {
   textstyles->notfixed = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1557,7 +1559,7 @@ yyreduce:
     break;
 
   case 14:
-#line 136 "./outlangdefparser.yy"
+#line 138 "./outlangdefparser.yy"
     {
   textstyles->color = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1565,7 +1567,7 @@ yyreduce:
     break;
 
   case 15:
-#line 142 "./outlangdefparser.yy"
+#line 144 "./outlangdefparser.yy"
     {
   textstyles->bg_color = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1573,7 +1575,7 @@ yyreduce:
     break;
 
   case 16:
-#line 148 "./outlangdefparser.yy"
+#line 150 "./outlangdefparser.yy"
     {
   textstyles->onestyle = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1581,7 +1583,7 @@ yyreduce:
     break;
 
   case 17:
-#line 154 "./outlangdefparser.yy"
+#line 156 "./outlangdefparser.yy"
     {
   textstyles->file_extension = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1589,7 +1591,7 @@ yyreduce:
     break;
 
   case 18:
-#line 160 "./outlangdefparser.yy"
+#line 162 "./outlangdefparser.yy"
     {
   textstyles->refstyle.anchor = TextStyle(*(yyvsp[(2) - (2)].string), anchor_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1597,7 +1599,7 @@ yyreduce:
     break;
 
   case 19:
-#line 166 "./outlangdefparser.yy"
+#line 168 "./outlangdefparser.yy"
     {
   textstyles->line_prefix = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1605,7 +1607,7 @@ yyreduce:
     break;
 
   case 20:
-#line 172 "./outlangdefparser.yy"
+#line 174 "./outlangdefparser.yy"
     {
   textstyles->linenum = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1613,7 +1615,7 @@ yyreduce:
     break;
 
   case 21:
-#line 178 "./outlangdefparser.yy"
+#line 180 "./outlangdefparser.yy"
     {
   if (textstyles->refstyle.inline_reference.empty())
     textstyles->refstyle.inline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
@@ -1626,7 +1628,7 @@ yyreduce:
     break;
 
   case 22:
-#line 189 "./outlangdefparser.yy"
+#line 191 "./outlangdefparser.yy"
     {
   textstyles->refstyle.inline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1634,7 +1636,7 @@ yyreduce:
     break;
 
   case 23:
-#line 195 "./outlangdefparser.yy"
+#line 197 "./outlangdefparser.yy"
     {
   textstyles->refstyle.postline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1642,7 +1644,7 @@ yyreduce:
     break;
 
   case 24:
-#line 201 "./outlangdefparser.yy"
+#line 203 "./outlangdefparser.yy"
     {
   textstyles->refstyle.postdoc_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1650,21 +1652,21 @@ yyreduce:
     break;
 
   case 25:
-#line 207 "./outlangdefparser.yy"
+#line 209 "./outlangdefparser.yy"
     {
   textstyles->colorMap = colorMap;
 }
     break;
 
   case 26:
-#line 212 "./outlangdefparser.yy"
+#line 214 "./outlangdefparser.yy"
     {
   textstyles->charTranslator = charTranslator;
 }
     break;
 
   case 27:
-#line 215 "./outlangdefparser.yy"
+#line 217 "./outlangdefparser.yy"
     {
             // this token is used by the scanner to signal an error
             // in opening an include file
@@ -1676,7 +1678,7 @@ yyreduce:
     break;
 
   case 31:
-#line 234 "./outlangdefparser.yy"
+#line 236 "./outlangdefparser.yy"
     {
   (*colorMap)[*(yyvsp[(1) - (2)].string)] = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(1) - (2)].string);
@@ -1685,7 +1687,7 @@ yyreduce:
     break;
 
   case 32:
-#line 241 "./outlangdefparser.yy"
+#line 243 "./outlangdefparser.yy"
     {
   colorMap->setDefault(*(yyvsp[(2) - (2)].string));
   delete (yyvsp[(2) - (2)].string);
@@ -1693,7 +1695,7 @@ yyreduce:
     break;
 
   case 36:
-#line 256 "./outlangdefparser.yy"
+#line 258 "./outlangdefparser.yy"
     {
   charTranslator->set_translation(*(yyvsp[(1) - (2)].string), *(yyvsp[(2) - (2)].string));
   delete (yyvsp[(1) - (2)].string);
@@ -1703,7 +1705,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1707 "outlangdefparser.cc"
+#line 1709 "outlangdefparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1917,7 +1919,7 @@ yyreturn:
 }
 
 
-#line 262 "./outlangdefparser.yy"
+#line 264 "./outlangdefparser.yy"
 
 
 extern int outlangdef_lex_destroy (void);
@@ -1934,6 +1936,8 @@ yyerror( const string &s )
   yyerror(s.c_str());
 }
 
+namespace srchilite {
+
 TextStylesPtr
 parse_outlang_def()
 {
@@ -1985,3 +1989,5 @@ parse_outlang_def(const char *path, const char *name)
   return textstyles;
 }
 
+}
+
